Ext.define('pfredispatch.BpcInterface', {extend:'BpcCommon.BpcInterface', config:{version:'4.0.0-SNAPSHOT', build:'4d8cc90-2023100416:27:21'}});
Ext.define('pfredispatch.Module', {singleton:true, name:'pfredispatch', constructor:function() {
  Ext.log('Loading pfredispatch Module...');
  var controller = BPC.getApplication().getController('BPC.controller.ModuleController');
  this.pluginModulesForMonitor = {};
  controller.getModuleInstances(this.name).each(function(moduleInstance) {
    var targetIndex = moduleInstance.settings().findExact('name', 'pluginMonitors');
    if (targetIndex >= 0) {
      Ext.each(moduleInstance.settings().getAt(targetIndex).data.value || [], function(t) {
        if (!this.pluginModulesForMonitor.hasOwnProperty(t)) {
          this.pluginModulesForMonitor[t] = [];
        } else {
          Ext.log({msg:this.name + ' createPlugin - multiple plugins for monitor' + t + ' are not useful.'});
        }
        this.pluginModulesForMonitor[t].push(moduleInstance);
      }, this);
    }
  }, this);
  controller.on('moduleInstanceCreated', this.maybeCreatePlugin, this);
  Ext.GlobalEvents.on('moduleInstanceComponentCreated', this.maybeCreatePlugin, this);
}, maybeCreatePlugin:function(moduleData) {
  if (moduleData.moduleBaseId === 'monitor') {
    Ext.each(this.pluginModulesForMonitor[moduleData.moduleInstanceId] || [], function(p) {
      Ext.log({msg:this.name + ' createPlugin ' + p.data.moduleId + ' for ' + moduleData.moduleInstanceId + '(' + moduleData.moduleBaseId + ')'});
      Ext.create(this.name + '.main.Plugin', {monitorAPI:moduleData.moduleInstance, proxyId:BpcCommon.Api.getSetting(moduleData.moduleInstanceId, 'inubit_proxyId'), monitorModuleId:moduleData.moduleInstanceId, settingStore:p.settings()}).activate();
    }, this);
  }
}, pluginModuleForMonitor:function(monitorModuleId) {
  var r = this.pluginModulesForMonitor[monitorModuleId];
  return r ? r[0].data.moduleId : undefined;
}, activateInstance:function(id) {
  Ext.log(this.self.getName() + ' ' + id);
}, deactivateInstance:function(id) {
  Ext.log(this.self.getName() + ' ' + id);
}, createInstance:function(id) {
  Ext.log(this.self.getName() + ' ' + id);
}, deleteInstance:function(id) {
  Ext.log(this.self.getName() + ' ' + id);
}});
Ext.define('pfredispatch.main.Plugin', {requires:[], constructor:function(config) {
  this.callParent(arguments);
  this.monitorAPI = config.monitorAPI;
  this.monitorModuleId = config.monitorModuleId;
  this.proxyId = config.proxyId;
  this.settingStore = config.settingStore;
}, settingValue:function(key, defaultValue) {
  var index = this.settingStore.findExact('name', key);
  return index >= 0 ? this.settingStore.getAt(index).data.value : defaultValue;
}, activate:function() {
  this.monitorAPI.on('destroy', this.destroy, this);
}, destroy:function() {
  this.callParent(arguments);
}});
Ext.define('pfredispatch.view.DetailColumn', {extend:'Ext.grid.column.Column', initComponent:function() {
  this.callParent(arguments);
  this.align = this.cellAlign;
}});
Ext.define('pfredispatch.view.DetailPanel', {extend:'Ext.panel.Panel', alias:'widget.pfredispatchDetailPanel', requires:['pfredispatch.view.DetailColumn'], title:'####PANEL####', scrollable:true, viewModel:{}, layout:{type:'vbox', align:'stretchmax'}, initComponent:function() {
  var m = BpcCommon.Api.getActiveModuleId();
  var p = pfredispatch.Module.pluginModuleForMonitor(m);
  if (p && this.record) {
    this.getViewModel().set('active', true);
    this.getViewModel().set('processID', this.record.data.PROCESSID);
    this.getViewModel().set('url', BpcCommon.Api.getBackendUrl(BpcCommon.Api.getSetting(m, 'inubit_proxyId')) + BpcCommon.Api.getSetting(p, 'url'));
  } else {
    this.showError('Zeitreihenansicht - anscheinend Fehlkonfiguration .');
  }
  this.callParent(arguments);
}, onRender:function() {
  this.callParent(arguments);
  this.setLoading(true);
  this.request = Ext.Ajax.request({url:this.getViewModel().get('url'), timeout:3600000, method:'POST', params:{request:'\x3croot\x3e\x3coperation\x3etimeSeriesData\x3c/operation\x3e\x3cprocessID\x3e' + Ext.String.htmlEncode(this.getViewModel().get('processID')) + '\x3c/processID\x3e\x3c/root\x3e'}, callback:function() {
    this.setLoading(false);
    delete this.request;
  }, success:this.dataLoaded, failure:function() {
    if (this.request) {
      this.showError('Fehler beim Abruf.');
    }
  }, scope:this});
}, onDestroy:function() {
  if (this.request) {
    this.request.cancel();
    delete this.request;
  }
  this.callParent(arguments);
}, dataLoaded:function(response) {
  try {
    var data = Ext.decode(response.responseText);
    if (String(data.success) === 'true') {
      error = undefined;
      this.showData(data);
    } else {
      this.showError(Ext.valueFrom(data.message, 'Fehler beim Abruf.'));
    }
  } catch (e) {
    this.showError('Fehler beim Abruf.');
    throw e;
  }
}, showError:function(message) {
  this.removeAll();
  this.add({padding:5, xtype:'displayfield', htmlEncode:true, value:message});
}, showData:function(data) {
  var columns = [];
  var fields = [];
  var gridWidth = 0;
  Ext.each(data.columns, function(c, index) {
    var width = Ext.Number.from(c.width, 100);
    fields.push(c.dataIndex);
    var d = {dataIndex:c.dataIndex, text:c.text, width:width, hideable:false, sortable:false, align:'left', cellAlign:'right'};
    gridWidth += width;
    columns.push(Ext.create('pfredispatch.view.DetailColumn', d));
  }, this);
  var store = Ext.create('Ext.data.Store', {fields:fields, data:data.data});
  var grid = Ext.create('Ext.grid.Panel', {anchor:'100% 100%', flex:1, width:100, minWidth:gridWidth + 20, columns:columns, store:store, emptyText:'Keine Zeitreihen', viewConfig:{deferEmptyText:false, enableTextSelection:true, enableColumnHide:true, enableColumnMove:false}});
  this.removeAll();
  if ('right' in data.head) {
    this.add({xtype:'container', anchor:'100%', layout:{type:'hbox', align:'stretch'}, padding:10, items:[{width:500, xtype:'displayfield', value:data.head.left}, {width:500, xtype:'displayfield', value:data.head.right}]});
  } else {
    this.add({xtype:'displayfield', value:data.head.left});
  }
  this.add(grid);
  Ext.Function.defer(function() {
    grid.setMinHeight(grid.getHeaderContainer().getHeight() + 150);
    this.updateLayout();
  }, 1, this);
}});
Ext.define('pfredispatch.view.Main', {extend:'Ext.container.Container', alias:'widget.pfredispatch', requires:[], layout:'fit', initComponent:function() {
  this.callParent();
}});
